DFMapping
=========

.. currentmodule:: hhpy.ds

.. autoclass:: DFMapping
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DFMapping.fit
      ~DFMapping.fit_transform
      ~DFMapping.from_df
      ~DFMapping.from_excel
      ~DFMapping.inverse_transform
      ~DFMapping.to_excel
      ~DFMapping.transform

   .. rubric:: Methods Documentation

   .. automethod:: fit
   .. automethod:: fit_transform
   .. automethod:: from_df
   .. automethod:: from_excel
   .. automethod:: inverse_transform
   .. automethod:: to_excel
   .. automethod:: transform
